/*global $, window, params*/
$(function () {
    "use strict";
    var $debugForm = $("#maintenance-form-record-debug-data");
    $debugForm.submit(function (e) {
        var record_time = $(this).find("#debug_record_time").val(),
            $button = $("#button-debug-download");
        e.preventDefault();
        $.ajax({
            type: "GET",
            url: "debug_download_prepare",
            cache: false,
            data: {
                record_time: record_time,
            },
            beforeSend: function () {
                $button.prop("disabled", true);
                $button.addClass("disabled");
                $button.addLoader("light");
            },
            success: function (data) {
                $button.prop("disabled", false);
                $button.removeClass("disabled");
                $button.removeLoader();
                if (data.status === "success") {
                    window.location.href = data.download_url;
                }
            },
            error: function (error) {
                console.log(error);
                $button.prop("disabled", false);
                $button.removeClass("disabled");
                $button.removeLoader();
            }
        });
    });
    $(".hasNotice").click(function (){
        var id = $(this).attr("id"),
            $parentDiv = $(this).parents(".maintenaceInner"),
            $notices = $parentDiv.find(".showOnClick.for-" + id);
        $notices.slideDown();
    });
    $("#button-restart-camera").click(function(e) {
        if ( confirm("This might take several minutes, do you want to continue?") ) {
            // Not tested with proxy
            $.ajax("/axis-cgi/admin/restart.cgi");
            $.waitForApp(false, 10000);
        }
        e.preventDefault();
    });
    $("#button-restart-framework").click(function(e) {
        e.preventDefault();
        $.restartAndWait();
    });

    $("#button-clear-registration").click(function(e) {

        function removeLicenseKeyInApp() {
            return $.ajax({
                type: "DELETE",
                url: "/stereo/license",
                success: function() {
                    console.debug("Successfully removed license key in application.");
                },
                error: function() {
                    createErrorCallback("Could not remove license key in application");
                }
            })
        }

        function removeLicenseKeyInCamera() {
            return $.ajax({
                method: "GET",
                url: "/axis-cgi/applications/license.cgi",
                data: {
                    action: "removelicensekey",
                    package: "startapp"
                },
                success: function() {
                    console.debug("Successfully removed key in camera.");
                },
                error: function() {
                    createErrorCallback("Could not remove license key in camera.");
                }
            });
        }

            function redirect() {
                $.waitForApp(function() {
                    window.location.href = "/stereo";
                });
            }

        if ( confirm("This will remove the current registration, do you want to continue?") ) {
            removeLicenseKeyInApp().done(function() {
                removeLicenseKeyInCamera().done(function() {
                    $.restartAndWait()
                    .done(redirect)
                    .fail(createErrorCallback("Could not restart app."));
                });
            });
        }

        e.preventDefault();
    });

    $("#button-registration-page").click(function(e) {
        window.location.href = "/stereo/registration.html";
        e.preventDefault();
    });

    $("#button-show-logs").click(function(e) {
        window.open("/logs/stereo.log");
        e.preventDefault();
    });

    $("#button-clear-data").click(function(e) {
        if ( confirm("This will remove all historical data, do you want to continue?") ) {
            $.post("/stereo/data/clear", {}, function(data) {
                if (data && data['status'] == 'CM_OK') {
                    $.waitForApp();
                } else {
                    if ( data && data['message'] ) {
                        alert("Could not clear data: " + data['message']);
                    } else {
                        alert("Could not clear data.");
                    }
                }
            }).fail(function() {
                alert("Could not clear data");
            });
        }
        e.preventDefault();
    });

    $("#button-upgrade").click(function(e) {
        e.preventDefault();
        if ( !confirm("This will download and install the latest version of this application. If the device is interrupted during this process you might lose data. Do you want to continue?") ) {
            return;
        }
        $.post('/local/startapp/cmd/upgrade', {}, function(data) {
            $('#overlay').show();
            if ( data && data.status == 'Ok' ) {
                window.status = 'Downloading package to device...'
                setTimeout(waitForDownload, 5000);
            } else {
                var msg = "Could not complete upgrade.";
                if ( data && data.status ) {
                    msg = "Could not complete upgrade: " + data.status;
                }
                alert(msg);
                $.waitForApp(function(){
                    window.location = "/stereo";
                });
            }
            function waitForDownload() {
                $.get('/local/startapp/status', function(data) {
                    if ( data && data.status == 'downloading' ) {
                        setTimeout(waitForDownload, 1000);
                    } else if ( data && data.status == 'installing' ) {
                        waitForInstallation();
                    } else if ( data && data.status == 'starting' ) {
                        waitForInstallation();
                    } else {
                        if ( data && data.status ) {
                            alert("Could not upgrade: " + data.status);
                        } else {
                            alert("Could not complete upgrade.");
                        }
                        $.waitForApp(function(){
                            window.location = "/stereo";
                        });
                    }
                }, "json");
            }
            function waitForInstallation() {
                $.get('/local/startapp/status', function(data) {
                    if ( data && data.status == 'installing' ) {
                        setTimeout(waitForDownload, 1000);
                    } else if ( data && data.status == 'starting' ) {
                        alert("Upgrade completed and the application is starting, please wait.");
                        // TODO: Add timeout
                        $.waitForApp(function(){
                            window.location = "/stereo";
                        });
                    } else {
                        if ( data && data.status ) {
                            alert("Could not upgrade: " + data.status);
                        } else {
                            alert("Could not complete upgrade!");
                        }
                        $.waitForApp(function(){
                            window.location = "/stereo";
                        });
                    }
                }, "json");
            }
        }, "json");
    });

    $.waitForAnon = function(callback, anonymize) {
        if ( anonymize == undefined ) {
            anonymize = true;
        }
        var pollTimer;
        setTimeout(function() {
            function pollAnon() {
                $.ajax("/stereo/anonymize/anonymized.json", {
                    success: function(data) {
                        if(data && data.anonymized == anonymize) {
                            if (callback) callback();
                        } else {
                            pollTimer = setTimeout(pollAnon, 2000);
                        }
                    }, error: function() {
                        pollTimer = setTimeout(pollAnon, 2000);
                    }
                });
            }
            pollAnon();
        }, 2000);
    }

    function createErrorCallback(message) {
        if (typeof message === 'undefined') {
            message = "An unknown error has occurred"
        }
        var func = function() {
            console.log(message);
        }
        return func;
    }
});
